@@ -5,37 +5,18 @@ use utf8;
 
 package WWW::Shorten::Akari;
 {
-  $WWW::Shorten::Akari::VERSION = 'v0.3.0';
+  $WWW::Shorten::Akari::VERSION = 'v0.1';
 }
 # ABSTRACT: Reduces the presence of URLs using http://waa.ai
 
 
-use parent qw{Exporter WWW::Shorten::generic};
-# must be exported by default; part of WWW::Shorten API
-our @EXPORT      = qw{makeashorterlink makealongerlink};
-our @EXPORT_OK   = qw{short_link long_link};
-our %EXPORT_TAGS = (
-    # not redundant; ":default" is part of the WWW::Shorten::generic import API
-    default => [@EXPORT],
-    short   => [@EXPORT_OK],
-);
-
-# Workaround for `use WWW::Shorten 'Akari'`.
-# Similar to the hack used within WWW::Shorten::generic with their
-# custom-implemented `import` method that doesn't respect empty
-# import lists.
-sub import {
-    my ($package) = caller;
-    __PACKAGE__->export_to_level(
-        $package eq 'WWW::Shorten' ? 2 : 1,
-        @_);
-}
+use base qw{WWW::Shorten::generic Exporter};
+our @EXPORT = qw{makeashorterlink makealongerlink};
 
 use constant API_URL => q{http://waa.ai/api.php};
 
 use Carp;
 use Encode qw{};
-use Scalar::Util qw{blessed};
 
 sub new {
     my $class = shift;
@@ -80,6 +61,11 @@ sub shorten {
     return $self->reduce(@args);
 }
 
+sub short_link {
+    my ($self, @args) = @_;
+    return $self->reduce(@args);
+}
+
 sub increase {
     my ($self, $url) = @_;
     unless ($url) {
@@ -106,34 +92,24 @@ sub lenghten {
     return $self->increase(@args);
 }
 
+sub long_link {
+    my ($self, @args) = @_;
+    return $self->increase(@args);
+}
+
 sub extract {
     my ($self, @args) = @_;
     return $self->increase(@args);
 }
 
-# Used by the functions when called as functions
 my $presence = WWW::Shorten::Akari->new;
 
-# Aliases to reduce when called as method; calls reduce on $presence when called as function
 sub makeashorterlink($) {
-    my $self = shift;
-    return $self->reduce(shift) if blessed($self) && $self->isa(__PACKAGE__);
-    return $presence->reduce($self);
+    return $presence->reduce(@_);
 }
 
-# Aliases to increase when called as method; calls increase on $presence when called as function
 sub makealongerlink($) {
-    my $self = shift;
-    return $self->increase(shift) if blessed($self) && $self->isa(__PACKAGE__);
-    return $presence->increase($self);
-}
-
-sub short_link($) { # merely redirects call, thus ignores prototypes
-    return &makeashorterlink(@_);
-}
-
-sub long_link($) { # merely redirects call, thus ignores prototypes
-    return &makealongerlink(@_);
+    return $presence->increase(@_);
 }
 
 1;
@@ -148,18 +124,18 @@ WWW::Shorten::Akari - Reduces the presence of URLs using http://waa.ai
 
 =head1 VERSION
 
-version v0.3.0
+version v0.1
 
 =head1 SYNOPSIS
 
     use WWW::Shorten::Akari;
 
-    my $presence = WWW::Shorten::Akari->new;
+    my $presence = WWW::Shorter::Akari->new;
     my $short = $presence->reduce("http://google.com");
     my $long  = $presence->increase($short);
 
-    $short = makeashorterlink("http://google.com");
-    $long  = makealongerlink($short);
+    $short = makeashortlink("http://google.com");
+    $long  = makealonglink($short);
 
 =head1 DESCRIPTION
 
@@ -181,7 +157,7 @@ Reduces the presence of the C<$url>. Returns the shortened URL.
 
 On failure, or if C<$url> is false, C<carp>s and returns false.
 
-Aliases: C<shorten>, C<short_link>, C<makeashorterlink>
+Aliases: C<shorten>, C<short_link>
 
 =head2 increase($url)
 
@@ -191,20 +167,7 @@ On failure, or if C<$url> is false, or if the C<$url> isn't
 a shortened link from L<http://waa.ai>, C<carp>s and returns
 false.
 
-Aliases: C<lenghten>, C<long_link>, C<extract>, C<makealongerlink>
-
-=head1 NOTES
-
-WWW::Shorten::Akari should preferrably be C<use>d with an empty list
-as arguments, like C<use WWW::Shorten::Akari qw{};>, and then used
-through the OO API.
-
-If no arguments are given to C<use>, WWW::Shorten::Akari is imported with
-':default' by default, which imports C<makeashorterlink> and
-C<makealongerlink> as per WWW::Shorten conventions. If the module is C<use>d
-with ':short', the functions C<short_link> and C<long_link> are imported.
-
-=for Pod::Coverage import
+Aliases: C<lenghten>, C<long_link>, C<extract>
 
 =for Pod::Coverage shorten short_link
 
@@ -214,20 +177,16 @@ with ':short', the functions C<short_link> and C<long_link> are imported.
 
 =head2 makeashorterlink($url)
 
-L<Makes a shorter link|http://tvtropes.org/pmwiki/pmwiki.php/Main/ExactlyWhatItSaysOnTheTin>.
-
-Alias: C<short_link>
+L<Makes a shorter link|http://tvtropes.org/pmwiki/pmwiki.php/Main/ExactlyWhatItSaysOnTheTin>
 
 =head2 makealongerlink($url)
 
 L<The opposite of|http://tvtropes.org/pmwiki/pmwiki.php/Main/CaptainObvious>
-L</makeashorterlink($url)>.
-
-Alias: C<long_link>
+L</makeashorterlink($url)>
 
 =head1 SOURCE CODE
 
-L<https://github.com/Kovensky/WWW-Shorten-Akari>
+https://github.com/Kovensky/WWW-Shorten-Akari
 
 =head1 AUTHOR
 
